function g = modelOutputGrad(model, X)

% MODELOUTPUTGRAD Compute derivatives with respect to params of model outputs.
%
%	Description:
%
%	G = MODELOUTPUTGRAD(MODEL, X) gives the gradients of the outputs
%	from the model with respect to the parameters for a given set of
%	inputs.
%	 Returns:
%	  G - gradients of the model output with respect to the model
%	   parameters for the given input locations.
%	 Arguments:
%	  MODEL - the model structure for which gradients are computed.
%	  X - input locations where gradients are to be computed.
%	
%
%	See also
%	MODELCREATE, MODELLOGLIKELIHOOD, MODELLOGLIKEGRADIENTS


%	Copyright (c) 2005, 2006 Neil D. Lawrence
% 	modelOutputGrad.m version 1.3


fhandle = str2func([model.type 'OutputGrad']);
gtemp = fhandle(model, X);

if isfield(model, 'paramGroups')
  g = zeros(size(X, 1), size(kern.paramGroups, 2), size(gtemp, 3));
  for i = 1:size(gtemp, 3)
    g = gtemp(:, :, i)*kern.paramGroups;
  end
else 
  g = gtemp;
end